@@ -764,7 +764,11 @@ where
 
     #[emitter]
     fn emit_str(&mut self, n: &Str) -> Result {
-        self.wr.write_raw(Some(n.span), &n.raw)?;
+        if self.config.minify {
+            self.wr.write_str(Some(n.span), &n.value)?;
+        } else {
+            self.wr.write_raw(Some(n.span), &n.raw)?;
+        }
     }
 
     #[emitter]
@@ -938,15 +942,64 @@ where
 
     #[emitter]
     fn emit_number(&mut self, n: &Number) -> Result {
-        self.wr.write_raw(Some(n.span), &n.raw)?;
+        if self.config.minify {
+            if n.value.is_sign_negative() && n.value == 0.0 {
+                self.wr.write_raw(Some(n.span), "-0")?;
+            } else {
+                let mut minified = n.value.to_string();
+
+                if minified.starts_with("0.") {
+                    minified.replace_range(0..1, "");
+                } else if minified.starts_with("-0.") {
+                    minified.replace_range(1..2, "");
+                }
+
+                if minified.starts_with(".000") {
+                    let mut cnt = 3;
+
+                    for &v in minified.as_bytes().iter().skip(4) {
+                        if v == b'0' {
+                            cnt += 1;
+                        } else {
+                            break;
+                        }
+                    }
+
+                    minified.replace_range(0..cnt + 1, "");
+
+                    let remain_len = minified.len();
+
+                    minified.push_str("e-");
+                    minified.push_str(&(remain_len + cnt).to_string());
+                } else if minified.ends_with("000") {
+                    let mut cnt = 3;
+
+                    for &v in minified.as_bytes().iter().rev().skip(3) {
+                        if v == b'0' {
+                            cnt += 1;
+                        } else {
+                            break;
+                        }
+                    }
+
+                    minified.truncate(minified.len() - cnt);
+                    minified.push('e');
+                    minified.push_str(&cnt.to_string());
+                }
+
+                self.wr.write_raw(Some(n.span), &minified)?;
+            }
+        } else {
+            self.wr.write_raw(Some(n.span), &n.raw)?;
+        }
     }
 
     #[emitter]
     fn emit_ration(&mut self, n: &Ratio) -> Result {
         emit!(self, n.left);
-        punct!(self, "/");
 
         if let Some(right) = &n.right {
+            punct!(self, "/");
             emit!(self, right);
         }
     }
